@@ -87,6 +87,7 @@ pub enum Tag<'a> {
     Image(Cow<'a, str>, Cow<'a, str>),
 }
 
+#[derive(Debug)]
 pub enum Event<'a> {
     Start(Tag<'a>),
     End(Tag<'a>),
@@ -750,6 +751,9 @@ impl<'a> RawParser<'a> {
         }
 
         let linktext = self.normalize_link_ref(&data[text_beg..text_end]);
+        if linktext.is_empty() {
+        	return false;
+        }
         if !self.links.contains_key(&linktext) {
             let dest = unescape(raw_dest);
             self.links.insert(linktext, (dest, title));
@@ -1487,4 +1491,3 @@ impl<'a> Iterator for RawParser<'a> {
         }
     }
 }
-
